/// <reference types="react" />
/// <reference types="@emotion/react" />
/// <reference types="theme-ui" />
/// <reference types="@emotion/core" />
import { Interpolation } from "../index";
import { ISizeType } from "../enum/size";
export declare enum EButtonType {
    primary = "primary",
    success = "success",
    warning = "warning",
    danger = "danger",
    info = "info",
    light = "light",
    dark = "dark"
}
export declare type IButtonTypeKey = keyof typeof EButtonType;
export declare type IButtonSizeKey = ISizeType;
export interface IButtonProps {
    /**
     * button type.
     */
    type?: IButtonTypeKey;
    /**
     * style of button wrapper.
     */
    style?: Interpolation;
    /**
     * button size.
     */
    size?: ISizeType;
    /**
     * button is disable or not.
     */
    disabled?: boolean;
    /**
     * text or react component in button.
     */
    children?: React.ReactNode;
    /**
     * button status is loading.
     */
    loading?: boolean;
    outline?: boolean;
    /**
     * handler of clicking button.
     */
    onClick?(): void;
    /**
     * whether the button's display property is block.
     */
    block?: boolean;
    /**
     * href prop of tag a
     */
    href?: string;
    /**
     * target prop of tag a
     */
    target?: string;
    link?: boolean;
}
export declare const Button: import("react").ForwardRefExoticComponent<IButtonProps & import("react").RefAttributes<HTMLLinkElement | HTMLButtonElement>>;
