/** @jsx jsx */
import { useMemo, forwardRef } from "react";
import { SolidCircleNotch } from "@fedlinker/font-awesome";
import { jsx } from "../index";
import { textColorTheme, transparentizeTheme, darkenTheme, } from "../utils/colors";
import { rotate } from "../utils/keyframes";
import { getCss } from "../theme";
export var EButtonType;
(function (EButtonType) {
    EButtonType["primary"] = "primary";
    EButtonType["success"] = "success";
    EButtonType["warning"] = "warning";
    EButtonType["danger"] = "danger";
    EButtonType["info"] = "info";
    EButtonType["light"] = "light";
    EButtonType["dark"] = "dark";
})(EButtonType || (EButtonType = {}));
export const Button = forwardRef((props, ref) => {
    const { style: cssProp, type, loading, onClick, children, size, disabled, block, href, target, outline, link, } = props;
    const handleClick = () => {
        if (loading || !onClick || disabled) {
            return;
        }
        onClick();
    };
    const typeStyles = useMemo(() => {
        return getCss(Object.assign({ backgroundColor: type, fontFamily: "body", color: textColorTheme(type) }, (disabled || loading
            ? {}
            : {
                "&:hover": {
                    backgroundColor: darkenTheme(type, 0.07),
                },
                "&:focus": {
                    backgroundColor: darkenTheme(type, 0.1),
                    boxShadow: t => `0 0 0 ${t.radii.sm} ${transparentizeTheme(type, 0.5)(t)}`,
                },
                "&:active": {
                    backgroundColor: darkenTheme(type, 0.15),
                },
            })));
    }, [type]);
    const sizeStyles = useMemo(() => {
        const isSm = size === "sm";
        const isLg = size === "lg";
        return getCss({
            padding: isLg ? 4 : isSm ? 2 : 3,
            paddingTop: isLg ? 2 : isSm ? 1 : 2,
            paddingBottom: isLg ? 2 : isSm ? 1 : 2,
            fontSize: isLg ? 3 : isSm ? 1 : 2,
        });
    }, [size]);
    const disabledStyles = useMemo(() => {
        return getCss(disabled
            ? {
                opacity: 0.65,
                cursor: "not-allowed",
            }
            : {});
    }, [disabled, type, outline]);
    const blockStyles = useMemo(() => {
        return block
            ? {
                display: "flex",
                width: "100%",
            }
            : {};
    }, [block]);
    const loadingStyles = useMemo(() => {
        return getCss(loading
            ? {
                opacity: 0.65,
                cursor: "progress",
            }
            : {});
    }, [loading]);
    const linkStyles = useMemo(() => {
        const backgroundColor = "rgba(0,0,0,0)";
        return link
            ? getCss({
                color: type,
                boxShadow: "none",
                backgroundColor,
                "&:hover": {
                    backgroundColor,
                    textDecoration: "underline",
                    color: darkenTheme(type, 0.075),
                },
                "&:focus": {
                    backgroundColor,
                    color: darkenTheme(type, 0.1),
                    boxShadow: "none",
                },
                "&:active": {
                    backgroundColor,
                    color: darkenTheme(type, 0.15),
                },
            })
            : {};
    }, [link, type]);
    const outlineStyles = useMemo(() => {
        return outline && !link
            ? getCss(Object.assign({ backgroundColor: "rgba(0,0,0,0)", borderColor: type, borderStyle: "solid", borderWidth: "1px", color: type }, (disabled || loading
                ? {}
                : {
                    "&:hover": {
                        backgroundColor: type,
                        color: textColorTheme(type),
                    },
                    "&:focus": {
                        backgroundColor: type,
                        color: textColorTheme(type),
                    },
                    "&:active": {
                        backgroundColor: type,
                    },
                })))
            : {};
    }, [outline, link, type, disabled]);
    const ElementType = useMemo(() => {
        return link ? "a" : "button";
    }, [link]);
    return (jsx(ElementType, { ref: ref, href: link ? href : undefined, target: link ? target : undefined, css: [
            {
                display: "inline-flex",
                position: "relative",
                alignItems: "center",
                outline: "none",
                borderRadius: "4px",
                transition: "all 0.3s",
                border: "none",
                cursor: "pointer",
                justifyContent: "center",
                verticalAlign: "middle",
            },
            typeStyles,
            sizeStyles,
            blockStyles,
            linkStyles,
            outlineStyles,
            cssProp || {},
            loadingStyles,
            disabledStyles,
        ], onClick: handleClick },
        loading ? (jsx(SolidCircleNotch, { css: {
                marginRight: "3px",
                animation: `${rotate} 1s linear infinite`,
            } })) : null,
        children));
});
Button.defaultProps = {
    type: "light",
    outline: false,
    size: "default",
};
