import React from "react";
import { Button } from "./index";
import { BrandsGithub } from "@fedlinker/font-awesome";
import { action } from "@storybook/addon-actions";
import { boolean } from "@storybook/addon-knobs";
export default { title: "Button", component: Button };
const types = [
    "primary",
    "success",
    "warning",
    "danger",
    "info",
    "light",
    "dark",
];
export const buttonType = () => {
    const margin = "12px";
    return types.map(t => {
        return (React.createElement(Button, { type: t, key: t, style: { margin }, onClick: action(t) }, t.toUpperCase()));
    });
};
export const linkButton = () => {
    return (React.createElement("div", null,
        React.createElement(Button, { type: "primary", link: true, href: "https://google.com", target: "_blank" }, "Link to google"),
        React.createElement(Button, { type: "danger", link: true, href: "https://google.com", target: "_blank" }, "Link to google")));
};
export const buttonSize = () => {
    var margin = "12px";
    const sizes = ["default", "lg", "sm"];
    return sizes.map((size, index) => {
        return (React.createElement(Button, { size: size, key: index, type: "primary", style: { margin } }, `size-${size || "default"}`));
    });
};
export const outlineButtons = () => {
    const margin = "12px";
    return types.map(t => {
        return (React.createElement(Button, { type: t, key: t, style: { margin }, outline: true }, t.toUpperCase()));
    });
};
export const disabledState = () => {
    const margin = "12px";
    return (React.createElement("div", null,
        React.createElement("div", null, types.map(t => {
            return (React.createElement(Button, { type: t, key: t, style: { margin }, disabled: boolean("disabled", true) }, t.toUpperCase()));
        })),
        React.createElement("div", null, types.map(t => {
            return (React.createElement(Button, { type: t, key: t, style: { margin }, disabled: true, outline: true }, t.toUpperCase()));
        }))));
};
export const blockState = () => {
    const marginTop = "12px";
    const margin = "12px";
    return (React.createElement("div", null,
        React.createElement("div", null, types.map(t => {
            return (React.createElement(Button, { type: t, key: t, style: { margin } }, t.toUpperCase()));
        })),
        React.createElement("div", null, types.map(t => {
            return (React.createElement(Button, { type: t, key: t, style: { marginTop }, block: true }, t.toUpperCase()));
        }))));
};
export const loadingState = () => {
    const loading = boolean("loading", true);
    var margin = "12px";
    return (React.createElement("div", null,
        React.createElement("div", null,
            "Button status: ",
            loading ? "Loading" : "Not loading",
            " "),
        React.createElement("div", null, types.map(t => {
            return (React.createElement(Button, { type: t, key: t, style: { margin }, loading: loading }, t.toUpperCase()));
        })),
        React.createElement("div", null, types.map(t => {
            return (React.createElement(Button, { type: t, key: t, style: { margin }, loading: loading, outline: true }, `${t.toUpperCase()} Outline`));
        })),
        React.createElement(Button, { block: true, loading: loading, type: "primary" }, "Primary Block Button"),
        React.createElement("div", null, "--"),
        React.createElement(Button, { block: true, loading: loading, type: "info", outline: true }, "Info Block Outline Button")));
};
export const addIcon = () => {
    const style = {
        marginBottom: "8px",
    };
    return (React.createElement("div", null,
        React.createElement("div", { style: style },
            React.createElement(Button, { type: "primary" },
                React.createElement(BrandsGithub, null),
                " Icon before")),
        React.createElement("div", { style: style },
            React.createElement(Button, { type: "success" },
                "Icon after ",
                React.createElement(BrandsGithub, null))),
        React.createElement("div", { style: style },
            React.createElement(Button, { type: "warning", block: true },
                React.createElement(BrandsGithub, null),
                " Icon block"))));
};
export const customButton = () => {
    const custom1 = {
        backgroundImage: "linear-gradient(30deg, #007bff, #28a745)",
        color: "#fff",
    };
    return (React.createElement("div", null,
        React.createElement("div", null,
            React.createElement(Button, { style: custom1, type: "primary" }, "Customize background color")),
        React.createElement("div", null, "---"),
        React.createElement("div", null,
            React.createElement(Button, { style: custom1, disabled: true }, "Customize background color")),
        React.createElement("div", null, "---"),
        React.createElement("div", null,
            React.createElement(Button, { style: custom1, loading: true }, "Customize background color"))));
};
