import React, { createContext, useContext } from "react";
import { DEFAULT_THEME } from "../theme";
export const ConfigContext = createContext({
    config: {
        theme: DEFAULT_THEME,
    },
    setConfig: () => null,
});
/**
 * config context hooks
 */
export const useConfig = () => {
    const { config, setConfig } = useContext(ConfigContext);
    return [config, setConfig];
};
/**
 * HOC to inject config context value
 * @param Comp component
 */
export const withConfig = (Comp) => {
    return (props) => {
        const [config, setConfig] = useConfig();
        return React.createElement(Comp, Object.assign({ config: config, setConfig: setConfig }, props));
    };
};
