import React from "react";
import { ConfigProvider } from "../config-provider";
import { Button, ButtonGroup } from "../../button";
import { useColorMode } from "../../theme/color-mode/color-mode-context";
import { BASE_COLORS } from "../../theme";
export default {
    title: "Config Provider",
    component: ConfigProvider,
};
const withConfigProvider = (Comp, config = {}) => {
    return (props) => {
        return (React.createElement(ConfigProvider, Object.assign({}, config),
            React.createElement(Comp, null, props.children)));
    };
};
export const BasicUsage = () => {
    return (React.createElement(ConfigProvider, null,
        React.createElement(Button, { type: "primary" }, "Custom Config")));
};
export const ColorMode = withConfigProvider(() => {
    const [colorMode, setColorMode] = useColorMode();
    return (React.createElement("div", null,
        React.createElement("div", null, colorMode),
        React.createElement("div", { style: { margin: "1rem 0" } },
            React.createElement(ButtonGroup, { size: "lg" },
                React.createElement(Button, { type: "primary" }, "primary"),
                React.createElement(Button, { type: "danger" }, "danger"),
                React.createElement(Button, { type: "info" }, "info"),
                React.createElement(Button, { type: "success" }, "success"),
                React.createElement(Button, { type: "warning" }, "warning"))),
        React.createElement(ButtonGroup, { type: "primary", outline: true },
            React.createElement(Button, { onClick: () => setColorMode("default") }, "default"),
            React.createElement(Button, { onClick: () => setColorMode("dark") }, "dark"))));
});
export const CustomTheme = withConfigProvider(() => {
    const [colorMode, setColorMode] = useColorMode();
    return (React.createElement("div", null,
        React.createElement("div", null, colorMode),
        React.createElement("div", { style: { margin: "1rem 0" } },
            React.createElement(ButtonGroup, { size: "lg" },
                React.createElement(Button, { type: "primary" }, "primary"),
                React.createElement(Button, { type: "danger" }, "danger"),
                React.createElement(Button, { type: "info" }, "info"),
                React.createElement(Button, { type: "success" }, "success"),
                React.createElement(Button, { type: "warning" }, "warning"))),
        React.createElement(ButtonGroup, { type: "primary", outline: true },
            React.createElement(Button, { onClick: () => setColorMode("default") }, "to default"),
            React.createElement(Button, { onClick: () => setColorMode("dark") }, "to dark"),
            React.createElement(Button, { onClick: () => setColorMode("myMode") }, "to myMode"))));
}, {
    config: {
        theme: {
            colors: {
                modes: {
                    myMode: {
                        text: BASE_COLORS.gray900,
                        secondary: BASE_COLORS.gray600,
                        background: BASE_COLORS.white,
                        primary: "#30B338",
                        success: "#59A1FF",
                        warning: "#FFA53F",
                        danger: "#FF342D",
                        info: "#FFE5B2",
                        light: BASE_COLORS.gray100,
                        dark: BASE_COLORS.gray800,
                        border: BASE_COLORS.gray300,
                        input: BASE_COLORS.gray700,
                        inputBorder: BASE_COLORS.gray400,
                        placeholder: BASE_COLORS.gray600,
                    },
                },
            },
        },
    },
    defaultColorMode: "myMode",
});
