/** @jsx jsx */
import { useMemo } from "react";
import { jsx, getCss } from "../theme";
// every row has 24 columns.
export const BASE_COLUMN_SIZE = 24;
const defaultFlexBasis = ["100%", 1, 1, 1, 1];
const calculateColsValue = (cols) => {
    if (typeof cols === "number") {
        // calculate the percent of every column.
        return `${(cols / BASE_COLUMN_SIZE) * 100}%`;
    }
    else if (typeof cols === "string") {
        return cols;
    }
    else {
        return 1;
    }
};
export const Col = props => {
    const { children, style = {}, cols } = props;
    const flexBasis = useMemo(() => {
        if (cols) {
            if (Array.isArray(cols)) {
                return cols.map((o) => calculateColsValue(o));
            }
            else {
                return calculateColsValue(cols);
            }
        }
        else {
            return defaultFlexBasis;
        }
    }, [cols]);
    const width = useMemo(() => {
        const calWidth = (w) => {
            return w === 1 ? "" : w;
        };
        if (Array.isArray(flexBasis)) {
            return flexBasis.map(o => calWidth(o));
        }
        else {
            return calWidth(flexBasis);
        }
    }, [flexBasis]);
    return (jsx("div", { css: [
            {
                flexGrow: 1,
                flexShrink: 1,
            },
            style,
            getCss({ width, flexBasis }),
        ] }, children));
};
Col.defaultProps = {
    style: {},
};
