import { darken, lighten, adjustHue, setHue, setSaturation, setLightness, desaturate, saturate, shade, tint, transparentize, rgba, mix, complement, invert, parseToRgb, } from "polished";
import { get } from "@styled-system/css";
import { BASE_COLORS } from "../theme";
const g = (t, c) => {
    return get(t, `colors.${c}`, c)
        .replace(/^var\(--(\w+)(.*?), /, "")
        .replace(/\)/, "");
};
export const darkenTheme = (c, n) => (t) => darken(n, g(t, c));
export const lightenTheme = (c, n) => (t) => lighten(n, g(t, c));
export const rotateTheme = (c, d) => (t) => adjustHue(d, g(t, c));
export const hueTheme = (c, h) => (t) => setHue(h, g(t, c));
export const saturationTheme = (c, s) => (t) => setSaturation(s, g(t, c));
export const lightnessTheme = (c, l) => (t) => setLightness(l, g(t, c));
export const desaturateTheme = (c, n) => (t) => desaturate(n, g(t, c));
export const saturateTheme = (c, n) => (t) => saturate(n, g(t, c));
export const shadeTheme = (c, n) => (t) => shade(n, g(t, c));
export const tintTheme = (c, n) => (t) => tint(n, g(t, c));
export const transparentizeTheme = (c, n) => (t) => transparentize(n, g(t, c));
export const alphaTheme = (c, n) => (t) => rgba(g(t, c), n);
export const mixTheme = (a, b, n = 0.5) => (t) => mix(n, g(t, a), g(t, b));
export const complementTheme = (c) => (t) => {
    return complement(g(t, c));
};
export const invertTheme = (c) => (t) => invert(g(t, c));
export const grayscaleTheme = (c, n) => desaturateTheme(c, 1);
/**
 * get the text color of the theme color type
 * @param color theme color type
 */
export const textColorTheme = (color) => (t) => {
    return textColor(g(t, color));
};
export const textColor = (color) => {
    const { red, green, blue } = parseToRgb(color);
    const yiq = (red * 299 + green * 587 + blue * 114) / 1000;
    if (yiq >= 150) {
        return BASE_COLORS.gray900;
    }
    else {
        return BASE_COLORS.white;
    }
};
